@@ -1,39 +1,33 @@
 use crate::prelude::*;
 use crate::vk;
 use crate::RawPtr;
-use crate::{EntryCustom, Instance};
+use crate::{Entry, Instance};
 use std::ffi::CStr;
 use std::mem;
 
 #[derive(Clone)]
 pub struct MacOSSurface {
     handle: vk::Instance,
-    macos_surface_fn: vk::MvkMacosSurfaceFn,
+    fp: vk::MvkMacosSurfaceFn,
 }
 
 impl MacOSSurface {
-    pub fn new<L>(entry: &EntryCustom<L>, instance: &Instance) -> Self {
-        let surface_fn = vk::MvkMacosSurfaceFn::load(|name| unsafe {
-            mem::transmute(entry.get_instance_proc_addr(instance.handle(), name.as_ptr()))
+    pub fn new(entry: &Entry, instance: &Instance) -> Self {
+        let handle = instance.handle();
+        let fp = vk::MvkMacosSurfaceFn::load(|name| unsafe {
+            mem::transmute(entry.get_instance_proc_addr(handle, name.as_ptr()))
         });
-        Self {
-            handle: instance.handle(),
-            macos_surface_fn: surface_fn,
-        }
+        Self { handle, fp }
     }
 
-    pub fn name() -> &'static CStr {
-        vk::MvkMacosSurfaceFn::name()
-    }
-
-    #[doc = "<https://www.khronos.org/registry/vulkan/specs/1.2-extensions/man/html/vkCreateMacOSSurfaceMVK.html>"]
+    /// <https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/vkCreateMacOSSurfaceMVK.html>
     pub unsafe fn create_mac_os_surface(
         &self,
         create_info: &vk::MacOSSurfaceCreateInfoMVK,
         allocation_callbacks: Option<&vk::AllocationCallbacks>,
     ) -> VkResult<vk::SurfaceKHR> {
         let mut surface = mem::zeroed();
-        self.macos_surface_fn
+        self.fp
             .create_mac_os_surface_mvk(
                 self.handle,
                 create_info,
@@ -43,8 +37,12 @@ impl MacOSSurface {
             .result_with_success(surface)
     }
 
+    pub fn name() -> &'static CStr {
+        vk::MvkMacosSurfaceFn::name()
+    }
+
     pub fn fp(&self) -> &vk::MvkMacosSurfaceFn {
-        &self.macos_surface_fn
+        &self.fp
     }
 
     pub fn instance(&self) -> vk::Instance {
